<?php

namespace Drupal\book_moderation_sync\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Book Moderation Sync settings for this site.
 */
class BookModerationSyncSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['book_moderation_sync.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'book_moderation_sync_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('book_moderation_sync.settings');

    $form['delete_children_on_book_delete'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Delete children when a book is deleted'),
      '#default_value' => $config->get('delete_children_on_book_delete'),
      '#description' => $this->t('When enabled, all child nodes of a book will be deleted when the book is deleted.'),
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('book_moderation_sync.settings')
      ->set('delete_children_on_book_delete', $form_state->getValue('delete_children_on_book_delete'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}